
* 2022 November 

* MS21-245 "COMPETITION AND BANK PAYOUT POLICY"
*
* Authors: 
* Dr Amedeo De Cesari (Alliance Manchester Business School, University of Manchester, UK)
* Dr Dudley Gilder (Cardiff Business School, Cardiff University, UK)
* Dr Winifred Huang (School of Management, University of Bath, UK)
* Professor Enrico Onali (University of Exeter Business School, University of Exeter, UK)

* Journal of Money, Credit and Banking

* SECTIONS BELOW IN ORDER:
* TABLES 
* APPENDICES
* FOOTNOTES
* FIGURES

* ===============================================================================
* TABLES 
* ===============================================================================
* ===============================================================================
* Import the ASCII file and save as a dta file
* ===============================================================================
clear all
global pathdata /*"insert path to file here"*/

import delimited "$pathdata\MS21_245_Data_1.txt", case(preserve)
gen dateq = yq(fyear, fqtr)  
format %tq dateq
save "$pathdata\MS21_245_Data_1.dta", replace
* ===============================================================================
* Table 2 Summary statistics
* ===============================================================================
	* =============================================================================================================
	* T2: a. statistics of variables (columns: Mean, Min, Median, Max, S.D., Obs.)
	* =============================================================================================================

	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	global SPLITS_w	"zscore_w roa_w roe_w"
	clear all
	use "$pathdata\MS21_245_Data_1.dta"
	local missscheck bank_bri_w BRIdummy $CONTROLS_w
	foreach nomiss of varlist `missscheck' {
	keep if `nomiss'!=.
	}
	gen raw_zscore = exp(zscore_1y)
	// Summary descriptive statistics
	local List1 "DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w bank_bri_w BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	quietly estpost tabstat `List1' ,  statistics( mean p50 min max sd N) columns(statistics) 
	esttab, label cell("mean min p50 max skewness  count") noobs  
	estout using "$pathdata\T2_BankDividends_stats_test.xls", cells("mean(fmt(3) label(Mean)) min(fmt(3) label(Min)) p50(fmt(3) label(Median)) max(fmt(3) label(Max)) sd(fmt(3) label(S.D.)) count(fmt(0) label(N))") label replace
	eststo clear
	
	* =============================================================================================================
	* T2: b. columns: Mean NSS, Mean SS, Difference
	* (this is to identify single-state banks - ie those that operate in a single state throughout the entire sample period)
	* =============================================================================================================
	gen singlestate=0
	replace singlestate=1 if bank_hhi==primary_state_hhi
	tempname descr
	postfile `descr' mean1 mean2 pvalore using "$pathdata/T2_descr.dta", replace
	foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w bank_bri_w BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w {
	ttest `K', by(singlestate) unequal
	scalar mean1=  r(mu_1)
	scalar mean2=  r(mu_2)
	scalar pvalore=r(p)
	post `descr' (mean1) (mean2) (pvalore)
	}
	postclose `descr'
	clear
	use "$pathdata/T2_descr.dta"
	export excel using "$pathdata/T2_BankDividends_stats_test_nss_ss.xlsx", firstrow(variables) replace
* Table 2 in the paper is from combining information in the files generated from above, that we summarised below: 
* T2_BankDividends_stats_test.xls, T2_BankDividends_stats_test_nss_ss
* =============================================================================================================
		
* =============================================================================================================
* Table 3 Baseline regressions of dividend and payout ratios on Bank BRI and a set of control variables.
* Standard Tobit, main Indep V.: bank_bri_w
* =============================================================================================================
	* =============================================================================================================
	* T3: Panel A. With State-Year FE
	* =============================================================================================================
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "bankid dateq fyear fyearq primary_state statedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w   " 
	local outcomelist "bank_bri_w BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	quietly {
	xi: tobit DIV_to_assets_w bank_bri_w $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
	outreg2 using "$pathdata\T3A", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist') addnote("winsorised variables") excel onecol replace
	margins, dydx(bank_bri_w) predict (ystar(0,.)) post
	outreg2 using "$pathdata\T3A_margins.doc", word replace ctitle(Marginal effects)
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
	xi: tobit `K' bank_bri_w $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
	outreg2 using "$pathdata\T3A", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel onecol append
	margins, dydx(bank_bri_w) predict (ystar(0,.)) post
	outreg2 using "$pathdata\T3A_margins.doc", word append ctitle(Marginal effects)
	}
	}
	
	* =============================================================================================================
	* T3: Panel B. With Bank FE
	* =============================================================================================================
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "bankid dateq fyearq statedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w " 
	local outcomelist "bank_bri_w BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	quietly {
	xi: tobit DIV_to_assets_w bank_bri_w $CONTROLS_w i.bankid if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
	outreg2 using "$pathdata\T3B", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist')   addnote("winsorised variables") excel word onecol replace
	margins, dydx(bank_bri_w) predict (ystar(0,.)) post
	outreg2 using "$pathdata\T3B_margins.doc", word replace ctitle(Marginal effects)
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
	xi: tobit `K' bank_bri_w $CONTROLS_w i.bankid if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
	outreg2 using "$pathdata\T3B", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel word onecol append
	margins, dydx(bank_bri_w) predict (ystar(0,.)) post
	outreg2 using "$pathdata\T3B_margins.doc", word append ctitle(Marginal effects)
	}
	}
* Table 3 in the paper is from combining information in the files generated from above, that we summarised below: 
* Table 3 - Panel A: T3A.xls, Panel B: T3B.xls
* =============================================================================================================
			
* =============================================================================================================
* Table 4 -  Baseline regressions of dividend and payout ratios on BRI dummy and a set of control variables.
* Standard Tobit, main Indep V.: BRIdummy
* =============================================================================================================
	* =============================================================================================================
	* T4: Panel A. With State-Year FE
	* =============================================================================================================
		clear all
		set matsize 8000
		use "$pathdata\MS21_245_Data_1.dta"
		global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
		global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
		global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
		egen pristate  = group(primary_state) // for state FE
		local keeplist "bankid dateq fyearq pristate statedateq pristatedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w" 
		local outcomelist "BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
		xtset bankid dateq, quarterly
		local append "replace"
		keep `keeplist'
			quietly {
			xi: tobit DIV_to_assets_w BRIdummy $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
			outreg2 using "$pathdata\T4A", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist')   addnote("winsorised variables") excel onecol replace
				margins, dydx(BRIdummy) predict (ystar(0,.)) post
				outreg2 using "$pathdata\T4A_margins.doc", word append ctitle(Marginal effects)
			
			foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
			xi: tobit `K' BRIdummy $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
			outreg2 using "$pathdata\T4A", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel onecol append
				margins, dydx(BRIdummy) predict (ystar(0,.)) post
				outreg2 using "$pathdata\T4A_margins.doc", word append ctitle(Marginal effects)
			}
			}
	
	* =============================================================================================================
	* T4: Panel B. With Bank FE
	* =============================================================================================================
		clear all
		set matsize 8000
		use "$pathdata\MS21_245_Data_1.dta"
		egen pristate  = group(primary_state) // for state FE
		global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
		global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
		global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
		local keeplist "bankid dateq fyearq pristate statedateq pristatedateq $DV_w $BANKVARS_w $CONTROLS_w" 
		local outcomelist "BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
		xtset bankid dateq, quarterly
		local append "replace"
		keep `keeplist'
			quietly {
			xi: tobit DIV_to_assets_w BRIdummy $CONTROLS_w i.bankid if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
			outreg2 using "$pathdata\T4B", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist')   addnote("winsorised variables") excel onecol replace
				margins, dydx(BRIdummy) predict (ystar(0,.)) post
				outreg2 using "$pathdata\T4B_margins.doc", word append ctitle(Marginal effects)
			
			foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
			xi: tobit `K' BRIdummy $CONTROLS_w i.bankid if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
			outreg2 using "$pathdata\T4B", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel onecol append
				margins, dydx(BRIdummy) predict (ystar(0,.)) post
				outreg2 using "$pathdata\T4B_margins.doc", word append ctitle(Marginal effects)
			}
			}					
* Table 4 in the paper is from combining information in the files generated from above, that we summarised below: 
* Table 4 - Panel A: T4A.xls, Panel B: T4B.xls
* =============================================================================================================

* =========================================================================================================
* Table 5 Probit regressions of Dividend increase on Bank BRI.
* Probit regressions: BRI on Dummy of dividend increases (D=1, otherwise 0 for div- or zero div) 
* =========================================================================================================
	* Save ASCII text file to dta file
	clear all
	global pathdata /*"insert path to file here"*/

	import delimited "$pathdata\MS21_245_Data_2.txt", case(preserve)
	gen dateq = yq(fyear, fqtr)  
	format %tq dateq
	save "$pathdata\MS21_245_Data_2.dta", replace

	* T5 regression
	
	use "$pathdata\MS21_245_Data_2.dta", clear 
	xtset bankid dateq, quarterly
	egen pristate  = group(primary_state) // for state FE
	global CONTROLS_w " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	global lagCONTROLS_w "lag_*"
	local keeplist "bankid dateq fyearq pristate statedateq pristatedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w" 
	local outcomelist "BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	local  KP  "l_bank_bri_w  " 
	local  KP2 "l_bank_bri_w $lagCONTROLS_w"
	* ssc install margeff
	set matsize 8000
	local append "replace"
	global Filename1 "$pathdata\T5_main.xls" 	// saving for the results of marginal effects
	global Filename2 "$pathdata\T5_marginaleffects_bankSE"
	global Filename3 "$pathdata\T5_marginaleffects_stateSE"
	set more off, perm
	*-- T5(cols 1&2) cluster by bank . Probit models - with lagged controls - state-year FE
	probit D_divinc l_bank_bri_w i.pristateyear, vce(cluster bankid)
		outreg2 using "$Filename1", keep(`KP' )  label excel ctitle(`DV') addtext(FE, state-year, StdErr_Cluster, Bank, Command, Probit, Sample, Full) stats(coef tstat) alpha(0.01,0.05,0.1) bdec(3) rdec(3) coefastr addstat(Pseudo R-squared, `e(r2_p)')   `append'
		local append "append"
		margins , dydx(l_bank_bri_w) atmeans
		outreg using "$Filename2",  stat(b se b_dfdx se_dfdx) bdec(3) nocons  starlevels(10 5 1) sigsymbols(*,**,***)  replace
	probit D_divinc l_bank_bri_w $lagCONTROLS_w i.pristateyear, vce(cluster bankid)
		outreg2 using "$Filename1", keep(`KP2' )  label excel ctitle(`DV') addtext(FE, state-year, StdErr_Cluster, Bank, Command, Probit, Sample, Full) stats(coef tstat) alpha(0.01,0.05,0.1) bdec(3) rdec(3) coefastr addstat(Pseudo R-squared, `e(r2_p)')   `append'
		local append "append"
		margins , dydx(l_bank_bri_w) atmeans
		outreg using "$Filename2",  stat(b se b_dfdx se_dfdx) bdec(3) nocons  starlevels(10 5 1) sigsymbols(*,**,***)  merge
	
	*-- T5(cols 3&4) cluster by state . Probit models - with lagged controls - state-year FE
	probit D_divinc l_bank_bri_w i.pristateyear, vce(cluster pristate)
		outreg2 using "$Filename1", keep(`KP' )  label excel ctitle(`DV') addtext(FE, state-year, StdErr_Cluster, State, Command, Probit, Sample, Full) stats(coef tstat) alpha(0.01,0.05,0.1) bdec(3) rdec(3) coefastr addstat(Pseudo R-squared, `e(r2_p)')   `append'
		local append "append"
		margins , dydx(l_bank_bri_w) atmeans
		outreg using "$Filename3",  stat(b se b_dfdx se_dfdx) bdec(3) nocons  starlevels(10 5 1) sigsymbols(*,**,***)  replace
	probit D_divinc l_bank_bri_w $lagCONTROLS_w i.pristateyear, vce(cluster pristate)
		outreg2 using "$Filename1", keep(`KP2' )  label excel ctitle(`DV') addtext(FE, state-year, StdErr_Cluster, State, Command, Probit, Sample, Full) stats(coef tstat) alpha(0.01,0.05,0.1) bdec(3) rdec(3) coefastr addstat(Pseudo R-squared, `e(r2_p)')   `append'
		local append "append"
		margins , dydx(l_bank_bri_w) atmeans
		outreg using "$Filename3",  stat(b se b_dfdx se_dfdx) bdec(3) nocons starlevels(10 5 1) sigsymbols(*,**,***)  merge

* Table 5 - T5_main.xls; marginal effects see T5_marginaleffects_bankSE.doc and T5_marginaleffects_stateSE.doc
* =============================================================================================================
					

* =========================================================================================================
* Table 6 Regressions of Bank BRI on payout ratios (Endogeneity test)
* =========================================================================================================
	* Save ASCII text file to dta file
	clear all
	global pathdata /*"insert path to file here"*/
	
	import delimited "$pathdata\MS21_245_Data_3.txt", case(preserve)
	gen dateq = yq(fyear, fqtr)  
	format %tq dateq
	save "$pathdata\MS21_245_Data_3.dta", replace

	* T6 regression
	*-- T6(cols 1 to 6)
	clear all
	use "$pathdata\MS21_245_Data_1.dta", clear 
	xtset bankid dateq, quarterly
	sort dateq dateq
	local missscheck " DVyear*_w  "
	foreach nomiss of varlist `missscheck' {
	keep if `nomiss'!=.
	}
	global FilenameT6a "$pathdata\T6_cols_1to6.xls"
	global KP "bankid dateq fyearq statedateq pristatedateq pristateyear bank_bri_w DVyear*_w "
	global keeplist " DVyear*_w   "
	local append "replace"
	keep $KP
	xtset bankid dateq, quarterly 
	foreach x2 of varlist DVyear*_w {	
		quietly reg bank_bri_w `x2'  i.pristatedateq  if fyearq<2007 & fyearq>=1994, vce(cluster bankid) 
		outreg2 using "$FilenameT6a", keep($keeplist) sortvar($keeplist) label stats(coef tstat) alpha(0.01,0.05,0.1) coefastr  adjr2  addstat(Banks,`e(N_clust)')  bdec(3) rdec(3) dec(3) excel  `append'
		local append "append"
		}
		
	*-- T6(cols 7 to 12)	
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_3.dta"
	global MACROVARS_w " L1_political_balance_w L1_real_GDP_capita_w L1_GDPPercCh_w L1_Unemploymentrate_w" // 
	global keeplist "DVyear*_w $MACROVARS_w"
	local missscheck " DVyear*_w $MACROVARS_w  " 
	foreach nomiss of varlist `missscheck' {
	keep if `nomiss'!=.
	}
	global FilenameT6b "$pathdata\T6_cols_7to12.xls"
	local append "replace"
	xtset bankid dateq, quarterly 		
	foreach x2 of varlist DVyear*_w{	
		quietly reg bank_bri_w `x2' $MACROVARS_w  i.pristatedateq  if fyearq<2007 & fyearq>=1994, vce(cluster bankid)
		outreg2 using "$FilenameT6b", keep($keeplist) sortvar($keeplist) label stats(coef tstat) alpha(0.01,0.05,0.1) coefastr  adjr2  addstat(Banks,`e(N_clust)') bdec(3) rdec(3) dec(3) excel  `append'
		local append "append"
		}

* Table 6 - Columns 1-6: T6_cols_1to6.xls and Columns 7-12: T6_cols_7to12
* =============================================================================================================


* =========================================================================================================
* Table 7 State-level probit regressions of the state interstate branching laws on payout ratios
* =========================================================================================================
	* Save ASCII text file to dta file
	clear all
	global pathdata /*"insert path to file here"*/
	
	import delimited "$pathdata\MS21_245_Data_4.txt", case(preserve)
	gen dateq = yq(fyear, fqtr) 
	format %tq dateq
	save "$pathdata\MS21_245_Data_4.dta", replace

	* T7 regression
	clear all
	use "$pathdata\MS21_245_Data_4.dta", clear 
	keep if BRIdummy_evt2!=.
	global L1_IV_w "L1_DIV_to_assets_w L1_DIV_to_MVE_w L1_DIV_to_ceq_w L1_TOTALPAYOUT_to_assets_w L1_TOTALPAYOUT_to_MVE_w L1_TOTALPAYOUT_to_ceq_w"		 
	global L1_MACROVARS_w "L1_political_balance_w L1_real_GDP_capita_w L1_GDPPercCh_w L1_Unemploymentrate_w"
	*drop dateqid
	egen pristateid = group(primary_state )
	egen dateqid  = group(dateq)
	xtset pristateid dateq
	egen pristatedateq = group(primary_state dateq)
	global keeplistmac " DVyear*_w $L1_IV_w $L1_MACROVARS_w "
	local append "replace"
	global FilenameT7 "$pathdata\T7.xls"
	xtset pristateid dateq, quarterly
	//probit: [state FE]
	foreach x2 of varlist DVyear*_w {	 
		probit BRIdummy_evt2 `x2' $L1_MACROVARS_w i.pristateid   , vce(cluster pristateid)
		outreg2 using "$FilenameT7", keep($keeplistmac) sortvar($keeplistmac) label stats(coef tstat) alpha(0.01,0.05,0.1) coefastr addstat(Pseudo R-squared, `e(r2_p)') addtext(Fixed effects, state) bdec(3) rdec(3) dec(3) excel  `append'		
		local append "append"
		}
	//probit: [Quarter FE]
	foreach x2 of varlist DVyear*_w {	 
		probit BRIdummy_evt2 `x2' $L1_MACROVARS_w  i.dateq  , vce(cluster pristateid)
		outreg2 using "$FilenameT7", keep($keeplistmac) sortvar($keeplistmac) label stats(coef tstat) alpha(0.01,0.05,0.1) coefastr addstat(Pseudo R-squared, `e(r2_p)')  addtext(Fixed effects, quarter)  bdec(3) rdec(3) dec(3) excel  `append'		
		local append "append"
		}	
		
* Table 7 - T7.xls 
* =============================================================================================================
					
					
* =========================================================================================================
* Table 8  Baseline regressions for non-bank financial firms.
* =========================================================================================================
	* Save ASCII text file to dta file
	clear all
	global pathdata /*"insert path to file here"*/
	
	import delimited "$pathdata\MS21_245_Data_5.txt", case(preserve)
	gen dateq = yq(fyear, fqtr) 
	format %tq dateq
	save "$pathdata\MS21_245_Data_5.dta", replace

	* =============================================================================================================
	* T8: Panel A. BRI dummy
	* =============================================================================================================
	quietly{
	clear all
	use "$pathdata\MS21_245_Data_5.dta", clear 
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* bri_w comp_state_bri_w"
	global CONTROLS_w " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "bankid dateq fyearq statedateq pristatedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w" 
	local outcomelist "BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
		quietly {
		xi: tobit DIV_to_assets_w BRIdummy $CONTROLS_w i.pristateyear  if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
		outreg2 using "$pathdata/T8A", label tstat r2 addstat(Number of Firms,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist')   addnote("winsorised variables") eqdrop(/) excel onecol replace
		
		foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
		xi: tobit `K' BRIdummy $CONTROLS_w i.pristateyear  if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
		outreg2 using "$pathdata/T8A", label tstat r2 addstat(Number of Firms,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsoried variables") eqdrop(/) excel onecol append
		}
		}
	}				
	* =============================================================================================================
	* T8: Panel B. BRI
	* =============================================================================================================
	
	clear all
	use "$pathdata\MS21_245_Data_5.dta", clear 
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* bri_w comp_state_bri_w"
	global CONTROLS_w " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "bankid dateq fyearq statedateq pristatedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w" 
	local outcomelist "BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
		quietly {
		xi: tobit DIV_to_assets_w bri_w $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
		outreg2 using "$pathdata/T8B", label tstat r2 addstat(Number of Firms,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(bri_w MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w)   addnote("winsorised variables") eqdrop(/) excel onecol replace
		foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
		xi: tobit `K' bri_w $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
		outreg2 using "$pathdata/T8B", label tstat r2 addstat(Number of Firms,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(bri_w MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w)   addnote("winsoried variables") eqdrop(/) excel onecol append
		}
	}
*  Table 8 - Panel A: T8A.xls, Panel B: T8B.xls
* =============================================================================================================
	

* =========================================================================================================
* Table 9  Sample split regressions.
* =========================================================================================================
	* =============================================================================================================
	* T9: Sample split by MTB
	* =============================================================================================================
	global pathdata /*"insert path to file here"*/	
	clear all
	set matsize 8000
	clear all
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	* no MTB in the control (only in this MTB-based sample split)
	global CONTROLS_w "Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	global SPLITS_w	"zscore_w roa_w roe_w Deposits_LT_w "
	local keeplist "bankid dateq fyearq primary_state pristate pristateyear $DV_w $BANKVARS_w $CONTROLS_w zscore_w MTB_w" 
	keep `keeplist'
	local outcomelist "bank_bri_w BRIdummy Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w MTB_w"
	xtset bankid dateq, quarterly
	set matsize 8000
	sort bankid fyear 
	foreach B of varlist MTB_w {  
		gen `B'_median=0 if `B'<.
		sum `B', detail
		replace `B'_median=1 if `B'>=r(p50) & `B'<.
		gen 	L_P50_`B'= 0 if `B'!=.
		replace L_P50_`B'= 1 if `B'_median==0  
		gen 	G_P50_`B'= 0 if `B'!=.
		replace G_P50_`B'= 1 if `B'_median==1  

		*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ P50 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
		local append "replace"
		quietly{
		foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
			foreach Q of varlist L_P50_`B' G_P50_`B' {
				xi: tobit `K' bank_bri_w $CONTROLS_w i.pristateyear if `Q'==1 & fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
				outreg2 using "$pathdata/T9_MTB", label tstat r2 addstat(Number of Banks,`e(N_clust)',Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'_`Q'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel onecol `append'
				local append "append"
			}
		  }
		}
	}
	* =============================================================================================================
	* T9: Sample split by Lerner and ROA, respectively
	* =============================================================================================================
	* Save ASCII text file to dta file
	clear all
	global pathdata /*"insert path to file here"*/	
	import delimited "$pathdata\MS21_245_Data_6.txt", case(preserve)
	gen dateq = yq(fyear, fqtr)  
	format %tq dateq
	save "$pathdata\MS21_245_Data_6.dta", replace
	
	* Regression 
	clear all
	set matsize 8000
	clear all
	use "$pathdata\MS21_245_Data_6.dta"
	egen pristate  = group(primary_state) // for state FE
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w "MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	global SPLITS_w	"zscore_w roa_w roe_w Deposits_LT_w Lerner_w"
	local keeplist  "bankid dateq fyearq primary_state pristate pristateyear $DV_w $BANKVARS_w $CONTROLS_w Lerner_w roa_w MTB_w" 
	keep `keeplist'
	local outcomelist "bank_bri_w BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	set matsize 8000
	sort bankid fyear 
	foreach B of varlist Lerner_w roa_w {  
		gen `B'_median=0   if `B'<.
		sum `B', detail
		replace `B'_median=1 if `B'>r(p50) & `B'<.
		gen 	L_P50_`B'= 0 if `B'!=.
		replace L_P50_`B'= 1 if `B'_median==0  
		gen 	G_P50_`B'= 0 if `B'!=.
		replace G_P50_`B'= 1 if `B'_median==1  
		*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ P50 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
		local append "replace"
		quietly{
		foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
			foreach Q of varlist L_P50_`B' G_P50_`B' {
			set more off, perm
				xi: tobit `K' bank_bri_w $CONTROLS_w i.pristateyear if `Q'==1 & fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
				outreg2 using "$pathdata\T9_`B'", label tstat r2 addstat(Number of Banks,`e(N_clust)',Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'_`Q'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel onecol `append'
				local append "append"
			}
		  }
		}
		}
	
	* =============================================================================================================
	* T9: Sample split by Zscore
	* =============================================================================================================
	global pathdata /*"insert path to file here"*/	
	clear all
	set matsize 8000
	clear all
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w "MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	global SPLITS_w	  "zscore_w roa_w roe_w Deposits_LT_w "
	local keeplist    "bankid dateq fyearq primary_state pristate pristateyear $DV_w $BANKVARS_w $CONTROLS_w  zscore* MTB_w" 
	keep `keeplist'
	local outcomelist "bank_bri_w BRIdummy Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w MTB_w"
	xtset bankid dateq, quarterly
	sort bankid fyear 
	foreach B of varlist zscore_1y {   
		gen `B'_median=0 if `B'<.
		sum `B', detail
		replace `B'_median=1 if `B'>=r(p50) & `B'<.
		gen 	L_P50_`B'= 0 if `B'!=.
		replace L_P50_`B'= 1 if `B'_median==0  
		gen 	G_P50_`B'= 0 if `B'!=.
		replace G_P50_`B'= 1 if `B'_median==1  
		*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ P50 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
		local append "replace"
		quietly {
		foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w{
		foreach Q of varlist L_P50_`B' G_P50_`B'{
		set more off, perm
			xi: tobit `K' bank_bri_w $CONTROLS_w i.pristateyear if `Q'==1 & fyearq<2007 & fyearq>=1994, ll(0) vce(cluster bankid)
			outreg2 using "$pathdata/T9_`B'", label tstat r2 addstat(Number of Banks,`e(N_clust)',Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'_`B'_`Q'") nocons  keep(bank_bri_w MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w)   addnote("winsorised variables") eqdrop(/) excel onecol `append'
			local append "append"
			}
			}
			}
		}
	
	* =============================================================================================================
	* T9: Sample split by Cash holdings
	* =============================================================================================================
	global pathdata /*"insert path to file here"*/	
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w "MTB_w Firm_size_w Cashflow_to_assets_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	global SPLITS_w	  "zscore_w roa_w roe_w Deposits_LT_w "
	local keeplist    " bankid dateq fyearq primary_state pristate pristateyear Cash_holdings_w $DV_w $BANKVARS_w $CONTROLS_w  zscore* MTB_w Cashflow_to_assets_w" 
	keep `keeplist'
	local outcomelist "bank_bri_w BRIdummy Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w MTB_w"
	xtset bankid dateq, quarterly
	sort bankid fyear 
	su Cashflow_to_assets_w
	foreach B of varlist Cash_holdings_w {   
	gen `B'_median=0 if `B'<.
	sum `B', detail
	replace `B'_median=1 if `B'>=r(p50) & `B'<.
	gen 	L_P50_`B'= 0 if `B'!=.
	replace L_P50_`B'= 1 if `B'_median==0  
	gen 	G_P50_`B'= 0 if `B'!=.
	replace G_P50_`B'= 1 if `B'_median==1  
	*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ P50 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	local append "replace"
	quietly {
	foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w{
	foreach Q of varlist L_P50_`B' G_P50_`B'{
	set more off, perm
		xi: tobit `K' bank_bri_w $CONTROLS_w i.pristateyear if `Q'==1 & fyearq<2007 & fyearq>=1994, ll(0) vce(cluster bankid)
		outreg2 using "$pathdata/T9_`B'", label tstat r2 addstat(Number of Banks,`e(N_clust)',Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'_`B'_`Q'") nocons  keep(`outcomelist') sortvar(`outcomelist')   addnote("winsorised variables") eqdrop(/) excel onecol `append'
		local append "append"
		}
		}
		}
	}
	*

* =========================================================================================================
* Table 10. Sample split regressions for single state, border county, and single state with and without border county.
* =========================================================================================================
	* =============================================================================================================
	* T10: Panel A: Sample split - single state
	* =============================================================================================================
	* Save ASCII text file to dta file
	clear all
	global pathdata /*"insert path to file here"*/	
	import delimited "$pathdata\MS21_245_Data_7.txt", case(preserve)
	gen dateq = yq(fyear, fqtr)  
	format %tq dateq
	save "$pathdata\MS21_245_Data_7.dta", replace
	
	* Regression 
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_7.dta"
	gen singlestate=0
	replace singlestate=1 if bank_hhi==primary_state_hhi
	global CONTROLS_w "MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local outcomelist "bank_bri_w MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	set matsize 8000
	*----[bank_bri_w]-main test bank bri
	local append "replace"
	quietly{
		foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
			forvalues singlestate_dummy=1(-1)0{
				xi: tobit `K' bank_bri_w $CONTROLS_w i.pristateyear if singlestate==`singlestate_dummy' & fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
				outreg2 using "$pathdata/T10A", label tstat r2 addstat(Number of Banks,`e(N_clust)',Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'_Single-state_`singlestate_dummy'") nocons  keep(`outcomelist')   addnote("winsoried variables") eqdrop(/) excel onecol `append'
				local append "append"
			}
		}
	}
	
	* =============================================================================================================
	* T10: Panel B: Sample split - border county
	* =============================================================================================================
	* Save ASCII text file to dta file
	clear all
	global pathdata /*"insert path to file here"*/	
	import delimited "$pathdata\MS21_245_Data_8.txt", case(preserve)
	gen dateq = yq(fyear, fqtr)  
	format %tq dateq
	save "$pathdata\MS21_245_Data_8.dta", replace
	
	* Regression 	
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_8.dta"
	* Create dummy for border_dep_perc above/below its median level
	gen border_dep_perc_p50=0 if border_dep_perc<.
	sum border_dep_perc if border_dep_perc<., detail
	replace border_dep_perc_p50=1 if border_dep_perc>=r(p50) & border_dep_perc<.
	gen singlestate=0
	replace singlestate=1 if bank_hhi==primary_state_hhi
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "border_dep_perc_p50 singlestate diff_state_bank bankid dateq fyear fyearq primary_state statedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w" 
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	quietly {
	forvalues border_dummy=1(-1)0{
	xi: tobit DIV_to_assets_w BRIdummy $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994 & diff_state_bank==`border_dummy', ll(0) vce(cluster bankid)
	outreg2 using "$pathdata/T10B", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA_border_dummy_`border_dummy'") nocons  keep(BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w)   addnote("winsorised variables") eqdrop(/) excel onecol `append'
	local append "append"
	}
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
		forvalues border_dummy=1(-1)0{
			xi: tobit `K' BRIdummy $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994 & diff_state_bank==`border_dummy',  ll(0) vce(cluster bankid)
			outreg2 using "$pathdata/T10B", label tstat r2 addstat(Number of Banks,`e(N_clust)',Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'_border_dummy_`border_dummy'") nocons  keep(BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w)   addnote("winsoried variables") eqdrop(/) excel onecol append
		}
	}
	}

	* =============================================================================================================
	* T10: Panel C: Sample split - single state and border county
	* =============================================================================================================
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_8.dta"
	* Create dummy for border_dep_perc above/below its median level
	gen border_dep_perc_p50=0 if border_dep_perc<.
	sum border_dep_perc if border_dep_perc<., detail
	replace border_dep_perc_p50=1 if border_dep_perc>=r(p50) & border_dep_perc<.
	gen singlestate=0
	replace singlestate=1 if bank_hhi==primary_state_hhi
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "border_dep_perc_p50 singlestate diff_state_bank bankid dateq fyear fyearq primary_state statedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w" 
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	quietly {
	forvalues border_dummy=1(-1)0{
	xi: tobit DIV_to_assets_w BRIdummy $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994 & diff_state_bank==`border_dummy' & singlestate==1, ll(0) vce(cluster bankid)
	outreg2 using "$pathdata/T10C", label tstat r2 addstat(Number of Banks,`e(N_clust)',Pseudo R-squared, `e(r2_p)') bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA_border_dummy_`border_dummy'") nocons  keep(BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w)   addnote("winsorised variables") eqdrop(/) excel onecol `append'
	local append "append"
	}
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
		forvalues border_dummy=1(-1)0{
			xi: tobit `K' BRIdummy $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994 & diff_state_bank==`border_dummy' & singlestate==1,  ll(0) vce(cluster bankid)
			outreg2 using "$pathdata/T10C", label tstat r2 addstat(Number of Banks,`e(N_clust)',Pseudo R-squared, `e(r2_p)') bdec(3) tdec(3) title("1994-2006") ctitle("`K'_border_dummy_`border_dummy'") nocons  keep(BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w)   addnote("winsoried variables") eqdrop(/) excel onecol append
		}
	}
	}
	
* =========================================================================================================
* Table 11. Baseline regressions of dividend and payout ratios on BRI dummy 2 and a set of control variables.
* =========================================================================================================
	* =============================================================================================================
	* T11: Panel A. State-Year FE
	* =============================================================================================================
	clear all
	use "$pathdata\MS21_245_Data_1.dta"
	set matsize 8000
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "bankid dateq fyearq statedateq pristatedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w BRI_jens" 
	local outcomelist "BRIdummy BRI_jens MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	quietly {
	xi: tobit DIV_to_assets_w BRI_jens $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
	outreg2 using "$pathdata\T11A", label tstat r2 addstat(Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist')   addnote("winsorised variables") excel onecol replace
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
	xi: tobit `K' BRI_jens $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
	outreg2 using "$pathdata\T11A", label tstat r2 addstat(Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel onecol append
	}
	}
		
	* =============================================================================================================
	* T11: Panel B. Bank FE
	* =============================================================================================================
	clear all
	use "$pathdata\MS21_245_Data_1.dta"
	set matsize 8000
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "bankid dateq fyearq statedateq pristatedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w BRI_jens" 
	local outcomelist "BRIdummy BRI_jens MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	quietly {
	xi: tobit DIV_to_assets_w BRI_jens $CONTROLS_w i.bankid if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
	outreg2 using "$pathdata\T11B", label tstat r2 addstat(Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist')   addnote("winsorised variables") excel onecol replace
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
	xi: tobit `K' BRI_jens $CONTROLS_w i.bankid if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
	outreg2 using "$pathdata\T11B", label tstat r2 addstat(Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel onecol append
	}
	}
	*

* =========================================================================================================
* Table 12  Distribution of the t-statistics for BRI dummy simulated and BRI dummy 2 simulated 
*           based on the Tobit models described in Eq. (2) and Eq. (4) with state-year fixed effects.
* =========================================================================================================
		clear all
		global pathdata /*"insert path to file here"*/

		import delimited "$pathdata\MS21_245_Data_sim.txt", case(preserve)
		gen dateq = yq(fyear, fqtr)  
		format %tq dateq
		save "$pathdata\MS21_245_Data_sim.dta", replace
		clear all
		import delimited "$pathdata\MS21_245_Data_sim2.txt", case(preserve)
		gen dateq = yq(fyearq, fqtr)  
		format %tq dateq
		save "$pathdata\MS21_245_Data_sim2.dta", replace

			
		* ===============================================================================
		* Table 4 -  ((( Baseline Regressions)))
		* Standard Tobit, main Indep V.: BRI dummy reshuffled
		* ===============================================================================
		//replication 1
			// Table 4 Panel A (state-year)
			clear all
			global pathdata /*"insert path to file here"*/

			use "$pathdata\MS21_245_Data_sim.dta", clear
			drop if BRIdummy==.
		set rngstream 1 
		set seed 204341
		tempname BRIdummy_placebo
		postfile `BRIdummy_placebo' placebo variable using $pathdata\ntable4_placebo_100, replace
		forvalues k=1(1)100 {
		di `k'
		display "$S_TIME  $S_DATE"
			quietly {
				sum BRIdummy, detail
				local osservazioni=r(N)
				gen double mischia=round(runiform()*`osservazioni')
				replace mischia=1 if mischia==0
				replace mischia=`osservazioni' if mischia>`osservazioni' & mischia<.
				sort mischia
				replace mischia=1 if 1/1
				replace mischia=mischia[_n-1]+1 in 2/`osservazioni'
				xtset bankidsim dateq, quarterly
				gen BRIdummy_placebo=.
				forvalues i=1(1)`osservazioni' {
				sum BRIdummy in `i'/`i'
				local prova=r(mean)
				sum mischia in `i'/`i'
				local prova2=r(mean)
				di 	`prova'
				di `prova2'
				replace BRIdummy_p=`prova' in `prova2'/`prova2'
				}
				foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
				xi: tobit `K' BRIdummy_placebo $CONTROLS_w i.pristateyear ,  ll(0) vce(cluster bankidsim)
				scalar variable=`k'
				scalar placebo=_b[BRIdummy_placebo]/_se[BRIdummy_placebo]
				post `BRIdummy_placebo' (placebo) (variable)
				}
			drop mischia* BRIdummy_placebo
			}
			}
			postclose `BRIdummy_placebo'
		use $pathdata\ntable4_placebo_100.dta, clear
		gen variable2=_n in 1/6	
		replace variable2=variable2[_n-6] in 7/600
		rename placebo tstat
		rename variable replication
		rename variable2 variable
		reshape wide tstat, i(replication) j(variable)
		save $pathdata\ntable4_placebo_reshape_100.dta, replace
		//replication 2
		clear all
		global pathdata /*"insert path to file here"*/

			use "$pathdata\MS21_245_Data_sim.dta", clear
			drop if BRIdummy==.
		set rngstream 2 
		set seed 204341
		tempname BRIdummy_placebo
		postfile `BRIdummy_placebo' placebo variable using $pathdata\ntable4_placebo_200, replace
		forvalues k=1(1)100 {
		di `k'
		display "$S_TIME  $S_DATE"
			quietly {
				sum BRIdummy, detail
				local osservazioni=r(N)
				gen double mischia=round(runiform()*`osservazioni')
				replace mischia=1 if mischia==0
				replace mischia=`osservazioni' if mischia>`osservazioni' & mischia<.
				sort mischia
				replace mischia=1 if 1/1
				replace mischia=mischia[_n-1]+1 in 2/`osservazioni'
				xtset bankidsim dateq, quarterly
				gen BRIdummy_placebo=.
				forvalues i=1(1)`osservazioni' {
				sum BRIdummy in `i'/`i'
				local prova=r(mean)
				sum mischia in `i'/`i'
				local prova2=r(mean)
				di 	`prova'
				di `prova2'
				replace BRIdummy_p=`prova' in `prova2'/`prova2'
				}
				foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
				xi: tobit `K' BRIdummy_placebo $CONTROLS_w i.pristateyear ,  ll(0) vce(cluster bankid)
				scalar variable=`k'
				scalar placebo=_b[BRIdummy_placebo]/_se[BRIdummy_placebo]
				post `BRIdummy_placebo' (placebo) (variable)
				}
			drop mischia* BRIdummy_placebo
			}
			}
			postclose `BRIdummy_placebo'
		use $pathdata\ntable4_placebo_200.dta, clear
		gen variable2=_n in 1/6	
		replace variable2=variable2[_n-6] in 7/600
		rename placebo tstat
		rename variable replication
		rename variable2 variable
		reshape wide tstat, i(replication) j(variable)
		save $pathdata\ntable4_placebo_reshape_200.dta, replace
		//replication 3
		clear all
		global pathdata /*"insert path to file here"*/

			use "$pathdata\MS21_245_Data_sim.dta", clear
			drop if BRIdummy==.
		set rngstream 3 
		set seed 204341
		tempname BRIdummy_placebo
		postfile `BRIdummy_placebo' placebo variable using $pathdata\ntable4_placebo_300, replace
		forvalues k=1(1)100 {
		di `k'
		display "$S_TIME  $S_DATE"
			quietly {
				sum BRIdummy, detail
				local osservazioni=r(N)
				gen double mischia=round(runiform()*`osservazioni')
				replace mischia=1 if mischia==0
				replace mischia=`osservazioni' if mischia>`osservazioni' & mischia<.
				sort mischia
				replace mischia=1 if 1/1
				replace mischia=mischia[_n-1]+1 in 2/`osservazioni'
				xtset bankid dateq, quarterly
				gen BRIdummy_placebo=.
				forvalues i=1(1)`osservazioni' {
				sum BRIdummy in `i'/`i'
				local prova=r(mean)
				sum mischia in `i'/`i'
				local prova2=r(mean)
				di 	`prova'
				di `prova2'
				replace BRIdummy_p=`prova' in `prova2'/`prova2'
				}
				foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
				xi: tobit `K' BRIdummy_placebo $CONTROLS_w i.pristateyear ,  ll(0) vce(cluster bankid)
				scalar variable=`k'
				scalar placebo=_b[BRIdummy_placebo]/_se[BRIdummy_placebo]
				post `BRIdummy_placebo' (placebo) (variable)
				}
			drop mischia* BRIdummy_placebo
			}
			}
			postclose `BRIdummy_placebo'
		use $pathdata\ntable4_placebo_300.dta, clear
		gen variable2=_n in 1/6	
		replace variable2=variable2[_n-6] in 7/600
		rename placebo tstat
		rename variable replication
		rename variable2 variable
		reshape wide tstat, i(replication) j(variable)
		save $pathdata\ntable4_placebo_reshape_300.dta, replace
		//replication 4
		clear all
		global pathdata /*"insert path to file here"*/

			use "$pathdata\MS21_245_Data_sim.dta", clear
			drop if BRIdummy==.
		set rngstream 4 
		set seed 204341
		tempname BRIdummy_placebo
		postfile `BRIdummy_placebo' placebo variable using $pathdata\ntable4_placebo_400, replace
		forvalues k=1(1)100 {
		di `k'
		display "$S_TIME  $S_DATE"
			quietly {
				sum BRIdummy, detail
				local osservazioni=r(N)
				gen double mischia=round(runiform()*`osservazioni')
				replace mischia=1 if mischia==0
				replace mischia=`osservazioni' if mischia>`osservazioni' & mischia<.
				sort mischia
				replace mischia=1 if 1/1
				replace mischia=mischia[_n-1]+1 in 2/`osservazioni'
				xtset bankid dateq, quarterly
				gen BRIdummy_placebo=.
				forvalues i=1(1)`osservazioni' {
				sum BRIdummy in `i'/`i'
				local prova=r(mean)
				sum mischia in `i'/`i'
				local prova2=r(mean)
				di 	`prova'
				di `prova2'
				replace BRIdummy_p=`prova' in `prova2'/`prova2'
				}
				foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
				xi: tobit `K' BRIdummy_placebo $CONTROLS_w i.pristateyear ,  ll(0) vce(cluster bankid)
				scalar variable=`k'
				scalar placebo=_b[BRIdummy_placebo]/_se[BRIdummy_placebo]
				post `BRIdummy_placebo' (placebo) (variable)
				}
			drop mischia* BRIdummy_placebo
			}
			}
			postclose `BRIdummy_placebo'
		use $pathdata\ntable4_placebo_400.dta, clear
		gen variable2=_n in 1/6	
		replace variable2=variable2[_n-6] in 7/600
		rename placebo tstat
		rename variable replication
		rename variable2 variable
		reshape wide tstat, i(replication) j(variable)
		save $pathdata\ntable4_placebo_reshape_400.dta, replace
		use $pathdata\ntable4_placebo_reshape_100.dta, clear
		append using $pathdata\ntable4_placebo_reshape_200.dta
		append using $pathdata\ntable4_placebo_reshape_300.dta
		append using $pathdata\ntable4_placebo_reshape_400.dta
		save $pathdata\ntable4_placebo_reshape_400all.dta, replace
		use $pathdata\ntable4_placebo_reshape_400all.dta, clear
		//construct critical values
		tempname BRIdummy_crit
		postfile `BRIdummy_crit' variable crit1 crit2 crit3 crit4 crit5 crit6 using $pathdata\ntable4_crit, replace
		forvalues i=1(1)6 {
		sort tstat`i'
		sum tstat`i' in 2/2
		scalar crit1=r(mean) 
		sum tstat`i' in 10/10
		scalar crit2=r(mean) 
		sum tstat`i' in 20/20
		scalar crit3=r(mean) 
		sum tstat`i' in 380/380
		scalar crit4=r(mean) 
		sum tstat`i' in 390/390
		scalar crit5=r(mean) 
		sum tstat`i' in 398/398
		scalar crit6=r(mean)
		scalar variable=`i'
		post `BRIdummy_crit' (variable) (crit1) (crit2) (crit3) (crit4) (crit5) (crit6)
		}
		postclose `BRIdummy_crit'

		* ===============================================================================
		* For Cornaggia
		* ===============================================================================
		///TABLE 4 - BRI DUMMY////
		//////////////////////////
		//replication 1 //////////
		//////////////////////////
		clear all
		global pathdata /*"insert path to file here"*/

			use "$pathdata\MS21_245_Data_sim.dta", clear
			encode primary_state, gen(primary_id)
			xtset bankidsim dateq, quarterly
		drop if primary_state==""
		gen BRIyyyymm_placebo=.
		gen BRIdummy_placebo =0 
		set rngstream 1 
		set seed 204341
		tempname BRIdummy_cornaggia
		postfile `BRIdummy_cornaggia' placebo variable using $pathdata\ntable_placebo_cornaggia1, replace
		forvalues k=1(1)100 {
		di `k'
		display "$S_TIME  $S_DATE"
		quietly {
		forvalues i=1(1)45 {
		scalar prova=round(runiform()*45)
		sum BRIyyyymm if primary_id==`i'
		scalar res1=r(mean)
		replace BRIyyyymm_placebo=res1 if primary_id==prova
		}
		forvalues i=1(1)45 {
		scalar prova2=round(runiform()*45)
		sum BRIyyyymm if primary_id==`i'
		scalar res1=r(mean)
		replace BRIyyyymm_placebo=res1 if primary_id==prova2 & BRIyyyymm_placebo==.
		}
		forvalues i=1(1)45 {
		scalar prova3=round(runiform()*45)
		sum BRIyyyymm if primary_id==`i'
		scalar res1=r(mean)
		replace BRIyyyymm_placebo=res1 if primary_id==prova3 & BRIyyyymm_placebo==.
		}
		replace BRIdummy_placebo =1 if yyyymm>=BRIyyyymm_placebo
		foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
		xi: tobit `K' BRIdummy_placebo $CONTROLS_w i.pristateyear ,  ll(0) vce(cluster bankidsim)
		scalar variable=`k'
		scalar placebo=_b[BRIdummy_placebo]/_se[BRIdummy_placebo]
		post `BRIdummy_cornaggia' (placebo) (variable)
		}
		}
		}
		postclose `BRIdummy_cornaggia'
		use $pathdata\ntable_placebo_cornaggia1.dta, clear
		gen variable2=_n in 1/6	
		replace variable2=variable2[_n-6] in 7/600
		rename placebo tstat
		rename variable replication
		rename variable2 variable
		reshape wide tstat, i(replication) j(variable)
		save $pathdata\ntable_cornaggia_reshape1.dta, replace
		//////////////////////////
		//replication 2 //////////
		//////////////////////////
		clear all
		clear all
		global pathdata /*"insert path to file here"*/

			use "$pathdata\MS21_245_Data_sim.dta", clear
			encode primary_state, gen(primary_id)
			xtset bankidsim dateq, quarterly
		drop if primary_state==""
		gen BRIyyyymm_placebo=.
		gen BRIdummy_placebo =0 
		set rngstream 2 
		set seed 204341
		tempname BRIdummy_cornaggia
		postfile `BRIdummy_cornaggia' placebo variable using $pathdata\ntable_placebo_cornaggia2, replace
		forvalues k=1(1)100 {
		di `k'
		display "$S_TIME  $S_DATE"
		quietly {
		forvalues i=1(1)45 {
		scalar prova=round(runiform()*45)
		sum BRIyyyymm if primary_id==`i'
		scalar res1=r(mean)
		replace BRIyyyymm_placebo=res1 if primary_id==prova
		}
		forvalues i=1(1)45 {
		scalar prova2=round(runiform()*45)
		sum BRIyyyymm if primary_id==`i'
		scalar res1=r(mean)
		replace BRIyyyymm_placebo=res1 if primary_id==prova2 & BRIyyyymm_placebo==.
		}
		forvalues i=1(1)45 {
		scalar prova3=round(runiform()*45)
		sum BRIyyyymm if primary_id==`i'
		scalar res1=r(mean)
		replace BRIyyyymm_placebo=res1 if primary_id==prova3 & BRIyyyymm_placebo==.
		}
		replace BRIdummy_placebo =1 if yyyymm>=BRIyyyymm_placebo
		foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
		xi: tobit `K' BRIdummy_placebo $CONTROLS_w i.pristateyear ,  ll(0) vce(cluster bankidsim)
		scalar variable=`k'
		scalar placebo=_b[BRIdummy_placebo]/_se[BRIdummy_placebo]
		post `BRIdummy_cornaggia' (placebo) (variable)
		}
		}
		}
		postclose `BRIdummy_cornaggia'
		use $pathdata\ntable_placebo_cornaggia2.dta, clear
		gen variable2=_n in 1/6	
		replace variable2=variable2[_n-6] in 7/600
		rename placebo tstat
		rename variable replication
		rename variable2 variable
		reshape wide tstat, i(replication) j(variable)
		save $pathdata\ntable_cornaggia_reshape2.dta, replace
		//////////////////////////
		//replication 3 //////////
		//////////////////////////
		clear all
		global pathdata /*"insert path to file here"*/

			use "$pathdata\MS21_245_Data_sim.dta", clear
			encode primary_state, gen(primary_id)
			xtset bankidsim dateq, quarterly
		drop if primary_state==""
		gen BRIyyyymm_placebo=.
		gen BRIdummy_placebo =0 
		set rngstream 3 
		set seed 204341
		tempname BRIdummy_cornaggia
		postfile `BRIdummy_cornaggia' placebo variable using $pathdata\ntable_placebo_cornaggia3, replace
		forvalues k=1(1)100 {
		di `k'
		display "$S_TIME  $S_DATE"
		quietly {
		forvalues i=1(1)45 {
		scalar prova=round(runiform()*45)
		sum BRIyyyymm if primary_id==`i'
		scalar res1=r(mean)
		replace BRIyyyymm_placebo=res1 if primary_id==prova
		}
		forvalues i=1(1)45 {
		scalar prova2=round(runiform()*45)
		sum BRIyyyymm if primary_id==`i'
		scalar res1=r(mean)
		replace BRIyyyymm_placebo=res1 if primary_id==prova2 & BRIyyyymm_placebo==.
		}
		forvalues i=1(1)45 {
		scalar prova3=round(runiform()*45)
		sum BRIyyyymm if primary_id==`i'
		scalar res1=r(mean)
		replace BRIyyyymm_placebo=res1 if primary_id==prova3 & BRIyyyymm_placebo==.
		}
		replace BRIdummy_placebo =1 if yyyymm>=BRIyyyymm_placebo
		foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
		xi: tobit `K' BRIdummy_placebo $CONTROLS_w i.pristateyear ,  ll(0) vce(cluster bankidsim)
		scalar variable=`k'
		scalar placebo=_b[BRIdummy_placebo]/_se[BRIdummy_placebo]
		post `BRIdummy_cornaggia' (placebo) (variable)
		}
		}
		}
		postclose `BRIdummy_cornaggia'
		use $pathdata\ntable_placebo_cornaggia3.dta, clear
		gen variable2=_n in 1/6	
		replace variable2=variable2[_n-6] in 7/600
		rename placebo tstat
		rename variable replication
		rename variable2 variable
		reshape wide tstat, i(replication) j(variable)
		save $pathdata\ntable_cornaggia_reshape3.dta, replace
		//////////////////////////
		//replication 4 //////////
		//////////////////////////
		clear all
		global pathdata /*"insert path to file here"*/

			use "$pathdata\MS21_245_Data_sim.dta", clear
			encode primary_state, gen(primary_id)
			xtset bankidsim dateq, quarterly
		drop if primary_state==""
		gen BRIyyyymm_placebo=.
		gen BRIdummy_placebo =0 
		set rngstream 4 
		set seed 204341
		tempname BRIdummy_cornaggia
		postfile `BRIdummy_cornaggia' placebo variable using $pathdata\ntable_placebo_cornaggia4, replace
		forvalues k=1(1)100 {
		di `k'
		display "$S_TIME  $S_DATE"
		quietly {
		forvalues i=1(1)45 {
		scalar prova=round(runiform()*45)
		sum BRIyyyymm if primary_id==`i'
		scalar res1=r(mean)
		replace BRIyyyymm_placebo=res1 if primary_id==prova
		}
		forvalues i=1(1)45 {
		scalar prova2=round(runiform()*45)
		sum BRIyyyymm if primary_id==`i'
		scalar res1=r(mean)
		replace BRIyyyymm_placebo=res1 if primary_id==prova2 & BRIyyyymm_placebo==.
		}
		forvalues i=1(1)45 {
		scalar prova3=round(runiform()*45)
		sum BRIyyyymm if primary_id==`i'
		scalar res1=r(mean)
		replace BRIyyyymm_placebo=res1 if primary_id==prova3 & BRIyyyymm_placebo==.
		}
		replace BRIdummy_placebo =1 if yyyymm>=BRIyyyymm_placebo
		foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
		xi: tobit `K' BRIdummy_placebo $CONTROLS_w i.pristateyear ,  ll(0) vce(cluster bankidsim)
		scalar variable=`k'
		scalar placebo=_b[BRIdummy_placebo]/_se[BRIdummy_placebo]
		post `BRIdummy_cornaggia' (placebo) (variable)
		}
		}
		}
		postclose `BRIdummy_cornaggia'
		use $pathdata\ntable_placebo_cornaggia4.dta, clear
		gen variable2=_n in 1/6	
		replace variable2=variable2[_n-6] in 7/600
		rename placebo tstat
		rename variable replication
		rename variable2 variable
		reshape wide tstat, i(replication) j(variable)
		save $pathdata\ntable_cornaggia_reshape4.dta, replace
		/////////////////////////////////////////////////////
		use $pathdata\ntable_cornaggia_reshape1.dta, clear
		append using $pathdata\ntable_cornaggia_reshape2.dta
		append using $pathdata\ntable_cornaggia_reshape3.dta
		append using $pathdata\ntable_cornaggia_reshape4.dta
		//critical values
		tempname BRIdummy_crit
		postfile `BRIdummy_crit' variable crit1 crit2 crit3 crit4 crit5 crit6 using $pathdata\ntable4_cornaggia_crit, replace
		forvalues i=1(1)6 {
		sort tstat`i'
		sum tstat`i' in 2/2
		scalar crit1=r(mean) 
		sum tstat`i' in 10/10
		scalar crit2=r(mean) 
		sum tstat`i' in 20/20
		scalar crit3=r(mean) 
		sum tstat`i' in 380/380
		scalar crit4=r(mean) 
		sum tstat`i' in 390/390
		scalar crit5=r(mean) 
		sum tstat`i' in 398/398
		scalar crit6=r(mean)
		scalar variable=`i'
		post `BRIdummy_crit' (variable) (crit1) (crit2) (crit3) (crit4) (crit5) (crit6)
		}
		postclose `BRIdummy_crit'
		* ===============================================================================
		* For BRI dummy2 reshuffled - redo based on BRI_jens
		* ===============================================================================
		//replication 1
		clear all
		global pathdata /*"insert path to file here"*/

			use "$pathdata\MS21_245_Data_sim2.dta", clear
			drop if BRI_jens==.
		set rngstream 1 
		set seed 204341
		tempname BRIdummy_placebo
		postfile `BRIdummy_placebo' placebo variable using $pathdata\ntable4_placebo_BRI_jens_100, replace
		forvalues k=1(1)100 {
		di `k'
		display "$S_TIME  $S_DATE"
			quietly {
				sum BRI_jens, detail
				local osservazioni=r(N)
				gen double mischia=round(runiform()*`osservazioni')
				replace mischia=1 if mischia==0
				replace mischia=`osservazioni' if mischia>`osservazioni' & mischia<.
				sort mischia
				replace mischia=1 if 1/1
				replace mischia=mischia[_n-1]+1 in 2/`osservazioni'
				xtset bankidsim dateq, quarterly
				gen BRIdummy_placebo=.
				forvalues i=1(1)`osservazioni' {
				sum BRI_jens in `i'/`i'
				local prova=r(mean)
				sum mischia in `i'/`i'
				local prova2=r(mean)
				di 	`prova'
				di `prova2'
				replace BRIdummy_p=`prova' in `prova2'/`prova2'
				}
				foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
				xi: tobit `K' BRIdummy_placebo $CONTROLS_w i.pristateyear ,  ll(0) vce(cluster bankidsim)
				scalar variable=`k'
				scalar placebo=_b[BRIdummy_placebo]/_se[BRIdummy_placebo]
				post `BRIdummy_placebo' (placebo) (variable)
				}
			drop mischia* BRIdummy_placebo
			}
			}
			postclose `BRIdummy_placebo'
		use $pathdata\ntable4_placebo_BRI_jens_100.dta, clear
		gen variable2=_n in 1/6	
		replace variable2=variable2[_n-6] in 7/600
		rename placebo tstat
		rename variable replication
		rename variable2 variable
		reshape wide tstat, i(replication) j(variable)
		save $pathdata\ntable4_placebo_reshape_BRI_jens_100.dta, replace
		//replication 2 
		clear all
		global pathdata /*"insert path to file here"*/

			use "$pathdata\MS21_245_Data_sim2.dta", clear
			drop if BRI_jens==.
		set rngstream 2 
		set seed 204341
		tempname BRIdummy_placebo
		postfile `BRIdummy_placebo' placebo variable using $pathdata\ntable4_placebo_BRI_jens_200, replace
		forvalues k=1(1)100 {
		di `k'
		display "$S_TIME  $S_DATE"
			quietly {
				sum BRI_jens, detail
				local osservazioni=r(N)
				gen double mischia=round(runiform()*`osservazioni')
				replace mischia=1 if mischia==0
				replace mischia=`osservazioni' if mischia>`osservazioni' & mischia<.
				sort mischia
				replace mischia=1 if 1/1
				replace mischia=mischia[_n-1]+1 in 2/`osservazioni'
				xtset bankidsim dateq, quarterly
				gen BRIdummy_placebo=.
				forvalues i=1(1)`osservazioni' {
				sum BRI_jens in `i'/`i'
				local prova=r(mean)
				sum mischia in `i'/`i'
				local prova2=r(mean)
				di 	`prova'
				di `prova2'
				replace BRIdummy_p=`prova' in `prova2'/`prova2'
				}
				foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
				xi: tobit `K' BRIdummy_placebo $CONTROLS_w i.pristateyear ,  ll(0) vce(cluster bankidsim)
				scalar variable=`k'
				scalar placebo=_b[BRIdummy_placebo]/_se[BRIdummy_placebo]
				post `BRIdummy_placebo' (placebo) (variable)
				}
			drop mischia* BRIdummy_placebo
			}
			}
			postclose `BRIdummy_placebo'
		use $pathdata\ntable4_placebo_BRI_jens_200.dta, clear
		gen variable2=_n in 1/6	
		replace variable2=variable2[_n-6] in 7/600
		rename placebo tstat
		rename variable replication
		rename variable2 variable
		reshape wide tstat, i(replication) j(variable)
		save $pathdata\ntable4_placebo_reshape_BRI_jens_200.dta, replace
		//replication 3 
		clear all
		global pathdata /*"insert path to file here"*/

			use "$pathdata\MS21_245_Data_sim2.dta", clear
			drop if BRI_jens==.
		set rngstream 3 
		set seed 204341
		tempname BRIdummy_placebo
		postfile `BRIdummy_placebo' placebo variable using $pathdata\ntable4_placebo_BRI_jens_300, replace
		forvalues k=1(1)100 {
		di `k'
		display "$S_TIME  $S_DATE"
			quietly {
				sum BRI_jens, detail
				local osservazioni=r(N)
				gen double mischia=round(runiform()*`osservazioni')
				replace mischia=1 if mischia==0
				replace mischia=`osservazioni' if mischia>`osservazioni' & mischia<.
				sort mischia
				replace mischia=1 if 1/1
				replace mischia=mischia[_n-1]+1 in 2/`osservazioni'
				xtset bankidsim dateq, quarterly
				gen BRIdummy_placebo=.
				forvalues i=1(1)`osservazioni' {
				sum BRI_jens in `i'/`i'
				local prova=r(mean)
				sum mischia in `i'/`i'
				local prova2=r(mean)
				di 	`prova'
				di `prova2'
				replace BRIdummy_p=`prova' in `prova2'/`prova2'
				}
				foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
				xi: tobit `K' BRIdummy_placebo $CONTROLS_w i.pristateyear ,  ll(0) vce(cluster bankidsim)
				scalar variable=`k'
				scalar placebo=_b[BRIdummy_placebo]/_se[BRIdummy_placebo]
				post `BRIdummy_placebo' (placebo) (variable)
				}
			drop mischia* BRIdummy_placebo
			}
			}
			postclose `BRIdummy_placebo'
		use $pathdata\ntable4_placebo_BRI_jens_300.dta, clear
		gen variable2=_n in 1/6	
		replace variable2=variable2[_n-6] in 7/600
		rename placebo tstat
		rename variable replication
		rename variable2 variable
		reshape wide tstat, i(replication) j(variable)
		save $pathdata\ntable4_placebo_reshape_BRI_jens_300.dta, replace
		//replication 4
		clear all
		global pathdata /*"insert path to file here"*/

			use "$pathdata\MS21_245_Data_sim2.dta", clear
			drop if BRI_jens==.
		set rngstream 4 
		set seed 204341
		tempname BRIdummy_placebo
		postfile `BRIdummy_placebo' placebo variable using $pathdata\ntable4_placebo_BRI_jens_400, replace
		forvalues k=1(1)100 {
		di `k'
		display "$S_TIME  $S_DATE"
			quietly {
				sum BRI_jens, detail
				local osservazioni=r(N)
				gen double mischia=round(runiform()*`osservazioni')
				replace mischia=1 if mischia==0
				replace mischia=`osservazioni' if mischia>`osservazioni' & mischia<.
				sort mischia
				replace mischia=1 if 1/1
				replace mischia=mischia[_n-1]+1 in 2/`osservazioni'
				xtset bankidsim dateq, quarterly
				gen BRIdummy_placebo=.
				forvalues i=1(1)`osservazioni' {
				sum BRI_jens in `i'/`i'
				local prova=r(mean)
				sum mischia in `i'/`i'
				local prova2=r(mean)
				di 	`prova'
				di `prova2'
				replace BRIdummy_p=`prova' in `prova2'/`prova2'
				}
				foreach K of varlist DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
				xi: tobit `K' BRIdummy_placebo $CONTROLS_w i.pristateyear ,  ll(0) vce(cluster bankidsim)
				scalar variable=`k'
				scalar placebo=_b[BRIdummy_placebo]/_se[BRIdummy_placebo]
				post `BRIdummy_placebo' (placebo) (variable)
				}
			drop mischia* BRIdummy_placebo
			}
			}
			postclose `BRIdummy_placebo'
		use $pathdata\ntable4_placebo_BRI_jens_400.dta, clear
		gen variable2=_n in 1/6	
		replace variable2=variable2[_n-6] in 7/600
		rename placebo tstat
		rename variable replication
		rename variable2 variable
		reshape wide tstat, i(replication) j(variable)
		save $pathdata\ntable4_placebo_reshape_BRI_jens_400.dta, replace
		//crit values
		global pathdata "**insert path to file here\" 
		 
		use $pathdata\ntable4_placebo_reshape_BRI_jens_100.dta, clear
		append using $pathdata\ntable4_placebo_reshape_BRI_jens_200.dta
		append using $pathdata\ntable4_placebo_reshape_BRI_jens_300.dta
		append using $pathdata\ntable4_placebo_reshape_BRI_jens_400.dta
		save $pathdata\ntable4_placebo_reshape_BRI_jens_400all.dta, replace
		use $pathdata\ntable4_placebo_reshape_BRI_jens_400all.dta, clear
		//construct critical values
		tempname BRIdummy_crit
		postfile `BRIdummy_crit' variable crit1 crit2 crit3 crit4 crit5 crit6 using $pathdata\ntable15_crit, replace
		forvalues i=1(1)6 {
		sort tstat`i'
		sum tstat`i' in 2/2
		scalar crit1=r(mean) 
		sum tstat`i' in 10/10
		scalar crit2=r(mean) 
		sum tstat`i' in 20/20
		scalar crit3=r(mean) 
		sum tstat`i' in 380/380
		scalar crit4=r(mean) 
		sum tstat`i' in 390/390
		scalar crit5=r(mean) 
		sum tstat`i' in 398/398
		scalar crit6=r(mean)
		scalar variable=`i'
		post `BRIdummy_crit' (variable) (crit1) (crit2) (crit3) (crit4) (crit5) (crit6)
		}
		postclose `BRIdummy_crit'



* =========================================================================================================
* Table 13  Price reaction to announcements of stable or increasing dividends per share (DPS), 
*           and predictability of bank performance using payout ratios.
* =========================================================================================================
	* Save ASCII text file to dta file
	clear all
	global pathdata /*"insert path to file here"*/	
	import delimited "$pathdata\MS21_245_Data_9.txt", case(preserve)
	gen dateq = yq(fyear, fqtr)  
	format %tq dateq
	save "$pathdata\MS21_245_Data_9.dta", replace
	
	* =============================================================================================================
	* T13: Panel A. CAR(-3,3)
	* =============================================================================================================
	clear all
	use "$pathdata\MS21_245_Data_9.dta"
	set matsize 8000
	local IVkeep bank* nodecr* dinc*  inc_* decr*  dec_* noincr* 
	reg car_33 nodecr  i.pristateyear if evento>19940000 & evento<. & bank_bri_w<=1 & bank_bri_w>0
		outreg2 using "$pathdata\T13A", keep(`IVkeep') label  excel addtext(State-year FE, YES)  stats(coef tstat) alpha(0.01,0.05,0.1) sortvar(`IVkeep') coefastr  adjr2  bdec(3) rdec(3) dec(3) replace
	reg car_33 nodecr  i.pristateyear if evento>19940000 & evento<. & bank_bri_w<=2 & bank_bri_w>1
		outreg2 using "$pathdata\T13A", keep(`IVkeep') label  excel addtext(State-year FE, YES)  stats(coef tstat) alpha(0.01,0.05,0.1) sortvar(`IVkeep') coefastr  adjr2  bdec(3) rdec(3) dec(3) append
	reg car_33 nodecr  i.pristateyear if evento>19940000 & evento<. & bank_bri_w<=3 & bank_bri_w>2 
		outreg2 using "$pathdata\T13A", keep(`IVkeep') label  excel addtext(State-year FE, YES)  stats(coef tstat) alpha(0.01,0.05,0.1) sortvar(`IVkeep') coefastr  adjr2  bdec(3) rdec(3) dec(3) append
	reg car_33 nodecr  i.pristateyear if evento>19940000 & evento<. & bank_bri_w<=4 & bank_bri_w>3
		outreg2 using "$pathdata\T13A", keep(`IVkeep') label  excel addtext(State-year FE, YES)  stats(coef tstat) alpha(0.01,0.05,0.1) sortvar(`IVkeep') coefastr  adjr2  bdec(3) rdec(3) dec(3) append
	reg car_33 nodecr  i.pristateyear if evento>19940000 & evento<. & bank_bri_w<=2 & bank_bri_w>0
		outreg2 using "$pathdata\T13A", keep(`IVkeep') label  excel addtext(State-year FE, YES)  stats(coef tstat) alpha(0.01,0.05,0.1) sortvar(`IVkeep') coefastr  adjr2  bdec(3) rdec(3) dec(3) append
	reg car_33 nodecr  i.pristateyear if evento>19940000 & evento<. & bank_bri_w<=4 & bank_bri_w>2
		outreg2 using "$pathdata\T13A", keep(`IVkeep') label  excel addtext(State-year FE, YES)  stats(coef tstat) alpha(0.01,0.05,0.1) sortvar(`IVkeep') coefastr  adjr2  bdec(3) rdec(3) dec(3) append
	
	* =============================================================================================================
	* T13: Panel B. CAR(-5,5)
	* =============================================================================================================
	clear all
	use "$pathdata\MS21_245_Data_9.dta"
	set matsize 8000
	local IVkeep bank* nodecr* dinc*  inc_* decr*  dec_* noincr* 
	reg car_55 nodecr  i.pristateyear if evento>19940000 & evento<. & bank_bri_w<=1 & bank_bri_w>0
		outreg2 using "$pathdata\T13B", keep(`IVkeep') label  excel addtext(State-year FE, YES)  stats(coef tstat) alpha(0.01,0.05,0.1) sortvar(`IVkeep') coefastr  adjr2  bdec(3) rdec(3) dec(3) replace
	reg car_55 nodecr  i.pristateyear if evento>19940000 & evento<. & bank_bri_w<=2 & bank_bri_w>1
		outreg2 using "$pathdata\T13B", keep(`IVkeep') label  excel addtext(State-year FE, YES)  stats(coef tstat) alpha(0.01,0.05,0.1) sortvar(`IVkeep') coefastr  adjr2  bdec(3) rdec(3) dec(3) append
	reg car_55 nodecr  i.pristateyear if evento>19940000 & evento<. & bank_bri_w<=3 & bank_bri_w>2 
		outreg2 using "$pathdata\T13B", keep(`IVkeep') label  excel addtext(State-year FE, YES)  stats(coef tstat) alpha(0.01,0.05,0.1) sortvar(`IVkeep') coefastr  adjr2  bdec(3) rdec(3) dec(3) append
	reg car_55 nodecr  i.pristateyear if evento>19940000 & evento<. & bank_bri_w<=4 & bank_bri_w>3
		outreg2 using "$pathdata\T13B", keep(`IVkeep') label  excel addtext(State-year FE, YES)  stats(coef tstat) alpha(0.01,0.05,0.1) sortvar(`IVkeep') coefastr  adjr2  bdec(3) rdec(3) dec(3) append
	reg car_55 nodecr  i.pristateyear if evento>19940000 & evento<. & bank_bri_w<=2 & bank_bri_w>0
		outreg2 using "$pathdata\T13B", keep(`IVkeep') label  excel addtext(State-year FE, YES)  stats(coef tstat) alpha(0.01,0.05,0.1) sortvar(`IVkeep') coefastr  adjr2  bdec(3) rdec(3) dec(3) append
	reg car_55 nodecr  i.pristateyear if evento>19940000 & evento<. & bank_bri_w<=4 & bank_bri_w>2
		outreg2 using "$pathdata\T13B", keep(`IVkeep') label  excel addtext(State-year FE, YES)  stats(coef tstat) alpha(0.01,0.05,0.1) sortvar(`IVkeep') coefastr  adjr2  bdec(3) rdec(3) dec(3) append
	

	
* ==========================================================================================================
* SUPPLEMENTARY APPENDICES
* =========================================================================================================	
* =========================================================================================================
* Table S.2 Baseline regressions of dividend and payout ratios on Bank BRI and a set of control variables.
* =========================================================================================================
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "bankid dateq fyear fyearq primary_state statedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w   " 
	local outcomelist "bank_bri_w BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	quietly {
	xi: tobit DIV_to_assets_w bank_bri_w $CONTROLS_w i.pristateyear i.bankid if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
		outreg2 using "$pathdata\Appendix_TableS2", label tstat r2 addstat(Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist') addnote("winsorised variables") excel onecol replace
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
	xi: tobit `K' bank_bri_w $CONTROLS_w i.pristateyear i.bankid if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
		outreg2 using "$pathdata\Appendix_TableS2", label tstat r2 addstat(Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel onecol append
	}
	}

* =========================================================================================================
* Table S.3 Baseline regressions of dividend and payout ratios on BRI dummy and a set of control variables. 
* =========================================================================================================
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	local keeplist "bankid dateq fyearq pristate statedateq pristatedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w" 
	local outcomelist "BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	quietly {
	xi: tobit DIV_to_assets_w BRIdummy $CONTROLS_w i.pristateyear i.bankid if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
	outreg2 using "$pathdata\Appendix_TableS3", label tstat r2 addstat(Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist')   addnote("winsorised variables") excel onecol replace
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
	xi: tobit `K' BRIdummy $CONTROLS_w i.pristateyear i.bankid if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
	outreg2 using "$pathdata\Appendix_TableS3", label tstat r2 addstat(Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel onecol append
	}
	}
	
* =========================================================================================================
* Table S.4 Baseline regressions of dividend and payout ratios on Primary State BRI and a set of control variables.
* =========================================================================================================
	* =============================================================================================================
	* Table S.4: Panel A
	* =============================================================================================================
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "bankid dateq fyear fyearq primary_state statedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w   " 
	local outcomelist "primary_state_bri_w BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	quietly {
	xi: tobit DIV_to_assets_w primary_state_bri_w $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
		outreg2 using "$pathdata\Appendix_TableS4_A", label tstat r2 addstat(Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist')   addnote("winsorised variables") excel onecol replace
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
	xi: tobit `K' primary_state_bri_w $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
		outreg2 using "$pathdata\Appendix_TableS4_A", label tstat r2 addstat(Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel onecol append
	}
	}
		
	* =============================================================================================================
	* Table S.4: Panel B
	* =============================================================================================================
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "bankid dateq fyear fyearq primary_state statedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w   " 
	local outcomelist "primary_state_bri_w BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	quietly {
	xi: tobit DIV_to_assets_w primary_state_bri_w $CONTROLS_w i.bankid if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
		outreg2 using "$pathdata\Appendix_TableS4_B", label tstat r2 addstat(Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist')   addnote("winsorised variables") excel onecol replace
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
	xi: tobit `K' primary_state_bri_w $CONTROLS_w i.bankid if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
		outreg2 using "$pathdata\Appendix_TableS4_B", label tstat r2 addstat(Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel onecol append
	}
	}	
	
* =========================================================================================================
* Table S.5 Baseline regressions of dividend and payout ratios on Bank BRI and a set of control variables using Honorè’s estimator.
* =========================================================================================================
	* =============================================================================================================
	* Table S.5: Panel A
	* =============================================================================================================
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "bankid dateq fyear fyearq primary_state statedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w   " 
	local outcomelist "bank_bri_w BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	set seed 124357
	pantob DIV_to_assets_w bank_bri_w $CONTROLS_w pristateyear if fyearq<2007 & fyearq>=1994,  bootstrap
		outreg2 using "$pathdata\Appendix_TableS5_A", label tstat r2 bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist') addnote("winsorised variables") excel onecol replace
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
		set seed 124357
	pantob `K' bank_bri_w $CONTROLS_w pristateyear if fyearq<2007 & fyearq>=1994,  bootstrap
		outreg2 using "$pathdata\Appendix_TableS5_A", label tstat r2 bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsorised variables") excel onecol append
	}
	*
	* =============================================================================================================
	* Table S.5: Panel B
	* =============================================================================================================
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "bankid dateq fyearq statedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w " 
	local outcomelist "bank_bri_w BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	set seed 124357
	pantob DIV_to_assets_w bank_bri_w $CONTROLS_w bankid if fyearq<2007 & fyearq>=1994,  bootstrap
		outreg2 using "$pathdata\Appendix_TableS5_B", label tstat r2  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist') addnote("winsorised variables") excel onecol replace
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
	set seed 124357
	pantob `K' bank_bri_w $CONTROLS_w bankid if fyearq<2007 & fyearq>=1994,  bootstrap
		outreg2 using "$pathdata\Appendix_TableS5_B", label tstat r2  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsorised variables") excel onecol append
	}
	*
	
* =========================================================================================================
* Table S.6 Baseline regressions of dividend and payout ratios on BRI dummy and a set of control variables using Honorè’s estimator.
* =========================================================================================================
	* =============================================================================================================
	* Table S.6: Panel A
	* =============================================================================================================
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	local keeplist "bankid dateq fyearq pristate statedateq pristatedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w" 
	local outcomelist "BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	set seed 124357
	pantob DIV_to_assets_w BRIdummy $CONTROLS_w pristateyear if fyearq<2007 & fyearq>=1994,  bootstrap 
		outreg2 using "$pathdata\Appendix_TableS6_A", label tstat r2  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist') addnote("winsorised variables") excel onecol replace
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
	set seed 124357
	pantob `K' BRIdummy $CONTROLS_w pristateyear if fyearq<2007 & fyearq>=1994,  bootstrap
		outreg2 using "$pathdata\Appendix_TableS6_A", label tstat r2  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsorised variables") excel onecol append
	}
	* =============================================================================================================
	* Table S.6: Panel B
	* =============================================================================================================
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "bankid dateq fyearq pristate statedateq pristatedateq $DV_w $BANKVARS_w $CONTROLS_w" 
	local outcomelist "BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	set seed 124357	
	pantob DIV_to_assets_w BRIdummy $CONTROLS_w bankid if fyearq<2007 & fyearq>=1994,  bootstrap
		outreg2 using "$pathdata\Appendix_TableS6_B", label tstat r2  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist') addnote("winsorised variables") excel onecol replace
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
	set seed 124357
	pantob `K' BRIdummy $CONTROLS_w bankid if fyearq<2007 & fyearq>=1994,  bootstrap
		outreg2 using "$pathdata\Appendix_TableS6_B", label tstat r2  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsorised variables") excel onecol append	
	}
	*
	
* ==========================================================================================================
* FOOTNOTES
* =========================================================================================================	
* Footnote 15. Robustness tests using state-level clustering produce virtually the same results.
	* =============================================================================================================
	* Footnote 15. part A (robust test for Table 3 Panel A)
	* =============================================================================================================
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "bankid dateq fyear fyearq primary_state statedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w   " 
	local outcomelist "bank_bri_w BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	quietly {
	xi: tobit DIV_to_assets_w bank_bri_w $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster pristate)
	outreg2 using "$pathdata\Footnote15_A", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist') addnote("winsorised variables") excel onecol replace
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
	xi: tobit `K' bank_bri_w $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster pristate)
	outreg2 using "$pathdata\Footnote15_A", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel onecol append
	}
	}
	* =============================================================================================================
	* Footnote 15. part B (robust test for Table 3 Panel B)
	* =============================================================================================================
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_1.dta"
	egen pristate  = group(primary_state) // for state FE
	global DV_w "DVyear*_w DIV_to_assets_w DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w"
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "bankid dateq fyearq statedateq pristateyear $DV_w $BANKVARS_w $CONTROLS_w " 
	local outcomelist "bank_bri_w BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	quietly {
	xi: tobit DIV_to_assets_w bank_bri_w $CONTROLS_w i.bankid if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster pristate)
	outreg2 using "$pathdata\Footnote15_B", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("DIV_TA") nocons  keep(`outcomelist')   addnote("winsorised variables") excel onecol replace
	foreach K of varlist DIV_to_MVE_w DIV_to_ceq_w TOTALPAYOUT_to_assets_w TOTALPAYOUT_to_MVE_w TOTALPAYOUT_to_ceq_w {
	xi: tobit `K' bank_bri_w $CONTROLS_w i.bankid if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster pristate)
	outreg2 using "$pathdata\Footnote15_B", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel onecol append
	}
	}

* =========================================================================================================
* Footnote 19.
/*
We also ran regressions with ROA, ROE, and net interest margins as a dependent variable, to check whether
the increase in payout ratios is due to an increase in profitability. If this were the case, it might be argued that our
results are driven by an increase in profitability following the enactment of IBBEA. However, the coefficients on
Bank BRI are insignificant.
*/
	* Save ASCII text file to dta file
	clear all
	global pathdata /*"insert path to file here"*/	
	import delimited "$pathdata\MS21_245_Data_footnote19.txt", case(preserve)
	gen dateq = yq(fyear, fqtr)  
	format %tq dateq
	save "$pathdata\MS21_245_Data_footnote19.dta", replace
	
	* Regression
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_footnote19.dta"
	egen pristate  = group(primary_state) // for state FE
	global BANKVARS_w "*BRIdummy* *bank_bri*_w bank_hhi_w comp_state_bri_w primary_state_bri_w comp_state_hhi_w primary_state_hhi_w"
	global CONTROLS_w    " MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w "
	local keeplist "roa_w roe_w NIM bankid dateq fyear fyearq primary_state statedateq pristateyear  $BANKVARS_w $CONTROLS_w   " 
	local outcomelist "bank_bri_w BRIdummy MTB_w Firm_size_w Cashflow_to_assets_w Cash_holdings_w Retained_earnings_w Leverage_w Firm_age_w syst_risk_w"
	xtset bankid dateq, quarterly
	local append "replace"
	keep `keeplist'
	quietly {
	xi: tobit roa_w bank_bri_w $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
	outreg2 using "$pathdata\Footnote19", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("roa_w") nocons  keep(`outcomelist') addnote("winsorised variables") excel onecol replace
	
	foreach K of varlist roe_w NIM {
	xi: tobit `K' bank_bri_w $CONTROLS_w i.pristateyear if fyearq<2007 & fyearq>=1994,  ll(0) vce(cluster bankid)
	outreg2 using "$pathdata\Footnote19", label tstat r2 addstat(Number of Banks,`e(N_clust)', Pseudo R-squared, `e(r2_p)')  bdec(3) tdec(3) title("1994-2006") ctitle("`K'") nocons  keep(`outcomelist')   addnote("winsoried variables") excel onecol append
	}
	}
* =========================================================================================================


* ==========================================================================================================
* FIGURES
* =========================================================================================================	
	clear all
	set matsize 8000
	use "$pathdata\MS21_245_Data_1.dta"
	gen singlestate=0
	replace singlestate=1 if bank_hhi==primary_state_hhi
	keep if fyearq<2007 & fyearq>=1994
	*To generate a separet dataset/table with the number of single and non-single state banks (and their ratio) use the following:
	bysort dateq: egen banknob_nss = count(bankid) if singlestate==0
	bysort dateq: egen banknob_total = count(bankid)
	gen banknob_ss = banknob_total-banknob_nss
	gen banknob_nssratio = banknob_nss/banknob_total
	keep if banknob_nss !=.
	duplicates drop dateq, force
	keep dateq banknob_nss banknob_ss banknob_total banknob_nssratio
	export excel using "$pathdata/ForFigures_SSAndNSS_summary.xlsx", firstrow(variables) replace //Use this dataset to create figures. Use values for last quarter of each year.
* In the file: SSAndNSS_summary(forFigures).xlsx
* Figure 1: We use data in column B divided by data in column C to generate data as ratios of non-single state banks to total banks.
* Figure 2: based on Column E (Number of non-single state banks and single state banks).
* =========================================================================================================	

	
	
	
	
	
